==> gurux_dlms-1.0.51.tar.gz: gurux_dlms-1.0.51/gurux_dlms/objects/enums/GsmPacketSwitchStatus.py <==
#
#  --------------------------------------------------------------------------
#   Gurux Ltd
#
#
#
#  Filename: $HeadURL$
#
#  Version: $Revision$,
#                   $Date$
#                   $Author$
#
#  Copyright (c) Gurux Ltd
#
# ---------------------------------------------------------------------------
#
#   DESCRIPTION
#
#  This file is a part of Gurux Device Framework.
#
#  Gurux Device Framework is Open Source software; you can redistribute it
#  and/or modify it under the terms of the GNU General Public License
#  as published by the Free Software Foundation; version 2 of the License.
#  Gurux Device Framework is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#  See the GNU General Public License for more details.
#
#  More information of Gurux products: http://www.gurux.org
#
#  This code is licensed under the GNU General Public License v2.
#  Full text may be retrieved at http://www.gnu.org/licenses/gpl-2.0.txt
# ---------------------------------------------------------------------------
#pylint: disable=broad-except,no-name-in-module
try:
    from enum import IntEnum
    __base = IntEnum
except Exception:
    __base = object

class GsmPacketSwitchStatus(__base):
    """
    Packet switched status of the modem.
    """
    #pylint: disable=too-few-public-methods

    #
    # Inactive
    #
    INACTIVE = 0
    #
    # GPRS
    #
    GPRS = 1
    #
    # EDGE
    #
    EDGE = 2
    #
    # UMTS
    #
    UMTS = 3
    #
    # HSDPA
    #
    HSDPA = 4
    #
    # LTE
    #
    LTE = 5
    #
    # CDMA
    #
    CDMA = 6

==> gurux_dlms-1.0.109.tar.gz: gurux_dlms-1.0.109/gurux_dlms/objects/enums/GsmPacketSwitchStatus.py <==
#
#  --------------------------------------------------------------------------
#   Gurux Ltd
#
#
#
#  Filename: $HeadURL$
#
#  Version: $Revision$,
#                   $Date$
#                   $Author$
#
#  Copyright (c) Gurux Ltd
#
# ---------------------------------------------------------------------------
#
#   DESCRIPTION
#
#  This file is a part of Gurux Device Framework.
#
#  Gurux Device Framework is Open Source software; you can redistribute it
#  and/or modify it under the terms of the GNU General Public License
#  as published by the Free Software Foundation; version 2 of the License.
#  Gurux Device Framework is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#  See the GNU General Public License for more details.
#
#  More information of Gurux products: http://www.gurux.org
#
#  This code is licensed under the GNU General Public License v2.
#  Full text may be retrieved at http://www.gnu.org/licenses/gpl-2.0.txt
# ---------------------------------------------------------------------------
from gurux_dlms.GXIntEnum import GXIntEnum

class GsmPacketSwitchStatus(GXIntEnum):
    """
    Packet switched status of the modem.
    """
    #pylint: disable=too-few-public-methods

    #
    # Inactive
    #
    INACTIVE = 0
    #
    # GPRS
    #
    GPRS = 1
    #
    # EDGE
    #
    EDGE = 2
    #
    # UMTS
    #
    UMTS = 3
    #
    # HSDPA
    #
    HSDPA = 4
    #
    # LTE
    #
    LTE = 5
    #
    # CDMA
    #
    CDMA = 6
